@@ -100,9 +100,23 @@ class GovCheckboxInput(GovCheckboxesInput):
 
 
 class GovRadioInput(GovIterableBase):
+    """Render radio button inputs.
+
+    Uses the field label as the fieldset legend.
+    """
     template = "govuk_frontend_wtf/radios.html"
     input_type = "radio"
 
+    def map_gov_params(self, field, **kwargs):
+        params = super().map_gov_params(field, **kwargs)
+        params.setdefault('fieldset', {
+            'legend': {
+                'text': field.label.text,
+                'classes': 'govuk-legend',
+            },
+        })
+        return params
+
 
 class GovDateInput(GovFormBase):
     """Renders three input fields representing Day, Month and Year.
@@ -125,9 +139,8 @@ class GovDateInput(GovFormBase):
 
     def map_gov_params(self, field, **kwargs):
         params = super().map_gov_params(field, **kwargs)
-        day, month, year = [None] * 3
-        if field.raw_data is not None:
-            day, month, year = field.raw_data
+        if field._value():
+            day, month, year = field._value().split(' ')
         params.setdefault('fieldset', {
             'legend': {
                 'text': field.label.text,
